utils

package
v0.0.0-...-928b0d8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 2, 2025 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

const Offset = 6

The offset in the callstack that Eventually introduces and needs to be unwinded if we want to report the line of the Eventually call itself (instead of the line in the lambda)

Variables

This section is empty.

Functions

func GetNonEmptyLines

func GetNonEmptyLines(output string) []string

GetNonEmptyLines converts given command output string into individual objects according to line breakers, and ignores the empty elements in it.

func GetPodNames

func GetPodNames(namespace, label string) ([]string, error)

GetPodNames returns the names of the pods in the given namespace with the given label.

func GetProjectDir

func GetProjectDir() (string, error)

GetProjectDir will return the directory where the project is

func Run

func Run(cmd *exec.Cmd) ([]byte, error)

Run executes the provided command within this context

Types

This section is empty.

Jump to